@@ -1,6 +1,6 @@
 package DateTime::Infinite;
 {
-  $DateTime::Infinite::VERSION = '0.78';
+  $DateTime::Infinite::VERSION = '1.00';
 }
 
 use strict;
@@ -38,9 +38,12 @@ sub STORABLE_thaw   {return}
 
 package DateTime::Infinite::Future;
 {
-  $DateTime::Infinite::Future::VERSION = '0.78';
+  $DateTime::Infinite::Future::VERSION = '1.00';
 }
 
+use strict;
+use warnings;
+
 use base qw(DateTime::Infinite);
 
 {
@@ -51,6 +54,7 @@ use base qw(DateTime::Infinite);
         local_rd_secs => DateTime::INFINITY,
         rd_nanosecs   => DateTime::INFINITY,
         tz            => DateTime::TimeZone->new( name => 'floating' ),
+        locale        => FakeLocale->instance(),
         },
         __PACKAGE__;
 
@@ -58,13 +62,16 @@ use base qw(DateTime::Infinite);
     $Pos->_calc_local_rd;
 
     sub new {$Pos}
-}
+ }
 
 package DateTime::Infinite::Past;
 {
-  $DateTime::Infinite::Past::VERSION = '0.78';
+  $DateTime::Infinite::Past::VERSION = '1.00';
 }
 
+use strict;
+use warnings;
+
 use base qw(DateTime::Infinite);
 
 {
@@ -75,6 +82,7 @@ use base qw(DateTime::Infinite);
         local_rd_secs => DateTime::NEG_INFINITY,
         rd_nanosecs   => DateTime::NEG_INFINITY,
         tz            => DateTime::TimeZone->new( name => 'floating' ),
+        locale        => FakeLocale->instance(),
         },
         __PACKAGE__;
 
@@ -84,6 +92,78 @@ use base qw(DateTime::Infinite);
     sub new {$Neg}
 }
 
+package    # hide from PAUSE
+    FakeLocale;
+
+use strict;
+use warnings;
+
+use DateTime::Locale;
+
+my $Instance;
+
+sub instance {
+    return $Instance ||= bless { locale => DateTime::Locale->load('en_US') },
+        __PACKAGE__;
+}
+
+sub id {
+    return 'infinite';
+}
+
+sub language_id {
+    return 'infinite';
+}
+
+sub name {
+    'Fake locale for Infinite DateTime objects';
+}
+
+sub language {
+    'Fake locale for Infinite DateTime objects';
+}
+
+my @methods = qw(
+    script_id
+    territory_id
+    variant_id
+    script
+    territory
+    variant
+    native_name
+    native_language
+    native_script
+    native_territory
+    native_variant
+);
+
+for my $meth (@methods) {
+    no strict 'refs';
+    *{$meth} = sub { undef };
+}
+
+# Totally arbitrary
+sub first_day_of_week {
+    return 1;
+}
+
+sub prefers_24_hour_time {
+    return 0;
+}
+
+our $AUTOLOAD;
+sub AUTOLOAD {
+    my $self = shift;
+
+    my ($meth) = $AUTOLOAD =~ /::(\w+)$/;
+
+    if ( $meth =~ /format/ && $meth !~ /^(?:day|month|quarter)/ ) {
+        return $self->{locale}->$meth(@_);
+    }
+
+    return [];
+}
+
 1;
 
 # ABSTRACT: Infinite past and future DateTime objects
@@ -98,7 +178,7 @@ DateTime::Infinite - Infinite past and future DateTime objects
 
 =head1 VERSION
 
-version 0.78
+version 1.00
 
 =head1 SYNOPSIS
 
@@ -150,7 +230,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2013 by Dave Rolsky.
 
 This is free software, licensed under:
 
